CREATE TABLE City
(
CityID          INTEGER,
ZipCode         NVARCHAR2(50),
City            NVARCHAR2(100),
State           NVARCHAR2(50),
AreaCode        NVARCHAR2(50),
Population2010  INTEGER
	DEFAULT 0,
Population2000  INTEGER
     DEFAULT 0,
Population1990  INTEGER
     DEFAULT 0,
Population1980  INTEGER
     DEFAULT 0,
Country         NVARCHAR2(50),
Latitude        NUMBER(15,5)
     DEFAULT 0,
Longitude       NUMBER(15,5)
     DEFAULT 0,
SelectionCDF    NUMBER(15,5)
     DEFAULT 0,
FIPS            INTEGER
     DEFAULT 0,
Income2009		NUMBER(25,4)
	DEFAULT 0,
Income2004      NUMBER(25,4)
     DEFAULT 0,
Division        INTEGER,
StateCode       INTEGER,
Region		INTEGER,
IntPtLat        NVARCHAR2(255),
IntPtLon        NVARCHAR2(255),
Housing2010	INTEGER,
AreaLand		NVARCHAR2(255),
AreaWater		NVARCHAR2(255),
     CONSTRAINT pk_City PRIMARY KEY (CityID)
);


CREATE TABLE Manufacturer
(
ManufacturerID    INTEGER,
ManufacturerName  NVARCHAR2(50),
ContactName       NVARCHAR2(100),
Phone             NVARCHAR2(100),
Address           NVARCHAR2(100),
ZipCode           NVARCHAR2(50),
CityID            INTEGER
     DEFAULT 0,
BalanceDue        NUMBER(25,4)
     DEFAULT 0,
     CONSTRAINT pk_Manufacturer PRIMARY KEY (ManufacturerID),
     CONSTRAINT fk_CityManufacturer FOREIGN KEY (CityID)
        REFERENCES City(CityID)
);


CREATE TABLE WorkArea
(
WorkArea      NVARCHAR2(100),
Description   NVARCHAR2(200),
     CONSTRAINT pk_WorkArea PRIMARY KEY (WorkArea)
);

CREATE TABLE Employee
(
EmployeeID     INTEGER,
TaxpayerID     NVARCHAR2(50),
LastName       NVARCHAR2(100),
FirstName      NVARCHAR2(100),
HomePhone      NVARCHAR2(100),
Address        NVARCHAR2(100),
ZipCode        NVARCHAR2(50),
CityID         INTEGER
     DEFAULT 0,
DateHired      DATE,
DateReleased   DATE,
CurrentManager INTEGER
     DEFAULT 0,
SalaryGrade    INTEGER
     DEFAULT 0,
Salary         NUMBER(25,4)
     DEFAULT 0,
Title          NVARCHAR2(200),
WorkArea       NVARCHAR2(100),
     CONSTRAINT pk_Employee PRIMARY KEY (EmployeeID),
     CONSTRAINT fk_CityEmployee FOREIGN KEY (CityID)
        REFERENCES City(CityID),
     CONSTRAINT fk_EmployeeWorkArea FOREIGN KEY (WorkArea)
        REFERENCES WorkArea(WorkArea)
);


CREATE TABLE RetailStore
(
StoreID           INTEGER,
StoreName         NVARCHAR2(100),
Phone             NVARCHAR2(100),
ContactFirstName  NVARCHAR2(50),
ContactLastName   NVARCHAR2(50),
Address           NVARCHAR2(100),
ZipCode           NVARCHAR2(50),
CityID            INTEGER
     DEFAULT 0,
     CONSTRAINT pk_RetailStore PRIMARY KEY (StoreID),
     CONSTRAINT fk_CityRetailStore FOREIGN KEY (CityID)
        REFERENCES City(CityID)
);

CREATE TABLE Customer
(
CustomerID    INTEGER,
Phone         NVARCHAR2(100),
FirstName     NVARCHAR2(100),
LastName      NVARCHAR2(100),
Gender        NVARCHAR2(50),
Address       NVARCHAR2(100),
ZipCode       NVARCHAR2(100),
CityID        INTEGER
     DEFAULT 0,
BalanceDue    NUMBER(25,4)
     DEFAULT 0,
     CONSTRAINT pk_Customer PRIMARY KEY (CustomerID),
     CONSTRAINT fk_CityCustomer FOREIGN KEY (CityID)
        REFERENCES City(CityID)
);

CREATE TABLE ModelType
(
ModelType     NVARCHAR2(100),
Description   NVARCHAR2(100),
ComponentID   INTEGER
     DEFAULT 0,
     CONSTRAINT pk_ModelType PRIMARY KEY (ModelType)
);

CREATE TABLE ModelSize
(
ModelType       NVARCHAR2(100),
MSize           NUMBER(15,5)
     DEFAULT 0,
TopTube         NUMBER(15,5)
     DEFAULT 0,
ChainStay       NUMBER(15,5)
     DEFAULT 0,
TotalLength     NUMBER(15,5)
     DEFAULT 0,
GroundClearance NUMBER(15,5)
     DEFAULT 0,
HeadTubeAngle   NUMBER(15,5)
     DEFAULT 0,
SeatTubeAngle   NUMBER(15,5)
     DEFAULT 0,
     CONSTRAINT pk_ModelSize PRIMARY KEY (ModelType,MSize),
     CONSTRAINT fk_Reference2 FOREIGN KEY (ModelType)
        REFERENCES ModelType(ModelType)
        ON DELETE CASCADE
);

CREATE TABLE ComponentName
(
ComponentName NVARCHAR2(100),
AssemblyOrder INTEGER
     DEFAULT 0,
Description   NVARCHAR2(200),
     CONSTRAINT pk_ComponentName PRIMARY KEY (ComponentName)
);

CREATE TABLE Component
(
ComponentID      INTEGER
     DEFAULT 0,
ManufacturerID   INTEGER
     DEFAULT 0,
ProductNumber    NVARCHAR2(100),
Road             NVARCHAR2(50),
Category         NVARCHAR2(100),
Length           NUMBER(15,5)
     DEFAULT 0,
Height           NUMBER(15,5)
     DEFAULT 0,
Width            NUMBER(15,5)
     DEFAULT 0,
Weight           NUMBER(15,5)
     DEFAULT 0,
Year             INTEGER
     DEFAULT 0,
EndYear          INTEGER
     DEFAULT 0,
Description      NVARCHAR2(400),
ListPrice        NUMBER(25,4)
     DEFAULT 0,
EstimatedCost    NUMBER(25,4)
     DEFAULT 0,
QuantityOnHand   NUMBER(15,5)
     DEFAULT 10,
     CONSTRAINT pk_Component PRIMARY KEY (ComponentID),
     CONSTRAINT fk_Reference FOREIGN KEY (Category)
        REFERENCES ComponentName(ComponentName)
        ON DELETE CASCADE,
     CONSTRAINT fk_Reference16 FOREIGN KEY (ManufacturerID)
        REFERENCES Manufacturer(ManufacturerID)
        ON DELETE CASCADE
);

CREATE TABLE TubeMaterial
(
TubeID        INTEGER
     DEFAULT 0,
Material      NVARCHAR2(100),
Description   NVARCHAR2(200),
Diameter      NUMBER(15,5)
     DEFAULT 0,
Thickness     NUMBER(15,5)
     DEFAULT 0,
Roundness     NVARCHAR2(100),
Weight        NUMBER(15,5)
     DEFAULT 0,
Stiffness     NUMBER(15,5)
     DEFAULT 0,
ListPrice     NUMBER(25,4)
     DEFAULT 1,
Construction  NVARCHAR2(100)
     DEFAULT 'Bonded',
     CONSTRAINT pk_TubeMaterial PRIMARY KEY (TubeID)
);

CREATE TABLE Paint
(
PaintID          INTEGER,
ColorName        NVARCHAR2(100),
ColorStyle       NVARCHAR2(100)
     DEFAULT 'Solid'
     CHECK (ColorStyle IN ('Solid', 'Two Color', 'Three Color', 'Special')),
ColorList        NVARCHAR2(100),
DateIntroduced   DATE,
DateDiscontinued DATE,
     CONSTRAINT pk_Paint PRIMARY KEY (PaintID)
);

CREATE TABLE CommonSizes
(
ModelType     NVARCHAR2(100),
FrameSize     NUMBER(15,5)
     DEFAULT 0 ,
     CONSTRAINT pk_CommonSizes PRIMARY KEY (ModelType,FrameSize)
);

CREATE TABLE Preference
(
ItemName      NVARCHAR2(100),
Value         NUMBER(15,5)
     DEFAULT 0,
Description   NVARCHAR2(500),
DateChanged   DATE,
     CONSTRAINT pk_Preference PRIMARY KEY (ItemName)
);

CREATE TABLE Groupo
(
ComponentGroupID  INTEGER,
GroupName         NVARCHAR2(100),
BikeType          NVARCHAR2(100),
Year              INTEGER,
EndYear           INTEGER,
WEIGHT            NUMBER(15,5),
     CONSTRAINT pk_Groupo PRIMARY KEY (ComponentGroupID)
);

CREATE TABLE LetterStyle
(
LetterStyle   NVARCHAR2(100),
Description   NVARCHAR2(100),
     CONSTRAINT pk_LetterStyle PRIMARY KEY (LetterStyle)
);

CREATE TABLE Bicycle
(
SerialNumber     INTEGER,
CustomerID       INTEGER
     DEFAULT 0,
ModelType        NVARCHAR2(100),
PaintID          INTEGER
     DEFAULT 0,
FrameSize        NUMBER(15,5)
     DEFAULT 0,
OrderDate        DATE,
StartDate        DATE,
ShipDate         DATE,
ShipEmployee     INTEGER
     DEFAULT 0,
FrameAssembler   INTEGER
     DEFAULT 0,
Painter          INTEGER
     DEFAULT 0,
Construction     NVARCHAR2(100)
     DEFAULT 'Bonded',
WaterBottleBrazeOns INTEGER
     DEFAULT 4,
CustomName       NVARCHAR2(100),
LetterStyleID    NVARCHAR2(100),
StoreID          INTEGER
     DEFAULT 0,
EmployeeID       INTEGER
     DEFAULT 0,
TopTube          NUMBER(15,5)
     DEFAULT 0,
ChainStay        NUMBER(15,5)
     DEFAULT 0,
HeadTubeAngle    NUMBER(15,5)
     DEFAULT 0,
SeatTubeAngle    NUMBER(15,5)
     DEFAULT 0,
ListPrice        NUMBER(25,4)
     DEFAULT 0,
SalePrice        NUMBER(25,4)
     DEFAULT 0,
SalesTax         NUMBER(25,4)
     DEFAULT 0,
SaleState        NVARCHAR2(100),
ShipPrice        NUMBER(25,4)
     DEFAULT 0,
FramePrice       NUMBER(25,4)
     DEFAULT 0,
ComponentList    NUMBER(25,4)
     DEFAULT 0,
     CONSTRAINT pk_Bicycle PRIMARY KEY (SerialNumber),
     CONSTRAINT fk_BikeModelType FOREIGN KEY (ModelType)
        REFERENCES ModelType(ModelType)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikeEmployee FOREIGN KEY (EmployeeID)
        REFERENCES Employee(EmployeeID)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikeRetail FOREIGN KEY (StoreID)
        REFERENCES RetailStore(StoreID)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikeCustomer FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikeLetter FOREIGN KEY (LetterStyleID)
        REFERENCES LetterStyle(LetterStyle)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikePaint FOREIGN KEY (PaintID)
        REFERENCES Paint(PaintID)
        ON DELETE CASCADE
);

CREATE TABLE BicycleTubeUsage
(
SerialNumber     INTEGER
     DEFAULT 0,
TubeID           INTEGER
     DEFAULT 0,
Quantity         NUMBER(15,5)
     DEFAULT 0,
     CONSTRAINT pk_BicycleTubeUsage PRIMARY KEY (SerialNumber,TubeID),
     CONSTRAINT fk_BikeTubeBike FOREIGN KEY (SerialNumber)
        REFERENCES Bicycle(SerialNumber)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikeTubeMaterial FOREIGN KEY (TubeID)
        REFERENCES TubeMaterial(TubeID)
        ON DELETE CASCADE
);

CREATE TABLE BikeParts
(
SerialNumber     INTEGER
     DEFAULT 0,
ComponentID      INTEGER
     DEFAULT 0,
SubstituteID     INTEGER
     DEFAULT 0,
Location         NVARCHAR2(100),
Quantity         INTEGER
     DEFAULT 0,
DateInstalled    DATE,
EmployeeID       INTEGER
     DEFAULT 0,
     CONSTRAINT pk_BikeParts PRIMARY KEY (SerialNumber,ComponentID),
     CONSTRAINT fk_BikePartsBike FOREIGN KEY (SerialNumber)
        REFERENCES Bicycle(SerialNumber)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikePartsEmp FOREIGN KEY (EmployeeID)
        REFERENCES Employee(EmployeeID)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikePartsComp FOREIGN KEY (ComponentID)
        REFERENCES Component(ComponentID)
        ON DELETE CASCADE
);

CREATE TABLE BikeTubes
(
SerialNumber  INTEGER
     DEFAULT 0,
TubeName      NVARCHAR2(100)
     CHECK (TubeName IN ('Top', 'Seat', 'Rear', 'Chain', 'Down', 'Front')),
TubeID        INTEGER
     DEFAULT 0,
Length        NUMBER(15,5)
     DEFAULT 0,
     CONSTRAINT pk_BikeTubes PRIMARY KEY (SerialNumber,TubeName),
     CONSTRAINT fk_BikeTubesBike FOREIGN KEY (SerialNumber)
        REFERENCES Bicycle(SerialNumber)
        ON DELETE CASCADE,
     CONSTRAINT fk_TubeMaterialBikeTubes FOREIGN KEY (TubeID)
        REFERENCES TubeMaterial(TubeID)
        ON DELETE CASCADE
);

CREATE TABLE CustomerTransaction
(
CustomerID       INTEGER
     DEFAULT 0,
TransactionDate  DATE,
EmployeeID       INTEGER
     DEFAULT 0,
Amount           NUMBER(25,4)
     DEFAULT 0,
Description      NVARCHAR2(250),
Reference        INTEGER
     DEFAULT 0,
     CONSTRAINT pk_CustomerTransaction PRIMARY KEY (CustomerID,TransactionDate),
     CONSTRAINT fk_CustTransCust FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE
);

CREATE TABLE GroupComponents
(
GroupID       INTEGER
     DEFAULT 0,
ComponentID   INTEGER
     DEFAULT 0,
     CONSTRAINT pk_GroupComponents PRIMARY KEY (GroupID,ComponentID),
     CONSTRAINT fk_GroupCompComp FOREIGN KEY (ComponentID)
        REFERENCES Component(ComponentID)
        ON DELETE CASCADE,
     CONSTRAINT fk_GroupCompGroup FOREIGN KEY (GroupID)
        REFERENCES Groupo(ComponentGroupID)
        ON DELETE CASCADE
);

CREATE TABLE ManufacturerTransaction
(
ManufacturerID   INTEGER
     DEFAULT 0,
TransactionDate  DATE,
EmployeeID       INTEGER
     DEFAULT 0,
Amount           NUMBER(25,4)
     DEFAULT 0,
Description      NVARCHAR2(500),
Reference        INTEGER
     DEFAULT 0,
     CONSTRAINT pk_ManufTransaction PRIMARY KEY (ManufacturerID,TransactionDate,Reference),
     CONSTRAINT fk_ManufTrans FOREIGN KEY (ManufacturerID)
        REFERENCES Manufacturer(ManufacturerID)
        ON DELETE CASCADE
);

CREATE TABLE PurchaseOrder
(
PurchaseID      INTEGER,
EmployeeID      INTEGER
     DEFAULT 0,
ManufacturerID  INTEGER
     DEFAULT 0,
TotalList       NUMBER(25,4)
     DEFAULT 0,
ShippingCost    NUMBER(25,4)
     DEFAULT 0,
Discount        NUMBER(25,4)
     DEFAULT 0,
OrderDate       DATE,
ReceiveDate     DATE,
AmountDue       NUMBER(25,4)
     DEFAULT 0,
     CONSTRAINT pk_PurchaseOrder PRIMARY KEY (PurchaseID),
     CONSTRAINT fk_PurchOrderManuf FOREIGN KEY (ManufacturerID)
        REFERENCES Manufacturer(ManufacturerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_PurchOrderEmp FOREIGN KEY (EmployeeID)
        REFERENCES Employee(EmployeeID)
        ON DELETE CASCADE
);

CREATE TABLE PurchaseItem
(
PurchaseID       INTEGER
     DEFAULT 0,
ComponentID      INTEGER
     DEFAULT 0,
PricePaid        NUMBER(25,4)
     DEFAULT 0,
Quantity         INTEGER
     DEFAULT 0,
QuantityReceived INTEGER
     DEFAULT 0,
     CONSTRAINT pk_PurchaseItem PRIMARY KEY (PurchaseID,ComponentID),
     CONSTRAINT fk_PurchItemPurch FOREIGN KEY (PurchaseID)
        REFERENCES PurchaseOrder(PurchaseID)
        ON DELETE CASCADE,
     CONSTRAINT fk_PurchItemComp FOREIGN KEY (ComponentID)
        REFERENCES Component(ComponentID)
        ON DELETE CASCADE
);

CREATE TABLE RevisionHistory
(
ID            INTEGER,
Version       NVARCHAR2(100),
ChangeDate    DATE,
Name          NVARCHAR2(100),
RevisionComments            NVARCHAR2(500),
     CONSTRAINT pk_RevisionHistory PRIMARY KEY (ID)
);

CREATE TABLE SampleName
(
ID            INTEGER,
LastName      NVARCHAR2(100),
FirstName     NVARCHAR2(100),
Gender        NVARCHAR2(50)
     CHECK (Gender IN ('M', 'F')),
     CONSTRAINT pk_SampleName PRIMARY KEY (ID)
);

CREATE TABLE SampleStreet
(
ID            INTEGER,
BaseAddress   NVARCHAR2(100),
     CONSTRAINT pk_SampleStreet PRIMARY KEY (ID)
);

CREATE TABLE CensusRegion
(
RegionID		INTEGER,
RegionName		NVARCHAR2(250),
	CONSTRAINT pk_CensusRegion PRIMARY KEY (RegionID)
);

CREATE TABLE CensusDivision
(
DivisionID		INTEGER,
DivisionName	NVARCHAR2(250),
RegionID		INTEGER,
	CONSTRAINT pk_CensusDivision PRIMARY KEY (DivisionID)
);

CREATE TABLE States
(
StateCode		INTEGER,
StateAbbrev	NVARCHAR2(10),
StateName		NVARCHAR2(100),
	CONSTRAINT pk_States PRIMARY KEY (StateCode)
);

CREATE TABLE StateTaxRate
(
State         NVARCHAR2(50),
TaxRate       NUMBER(15,5)
     DEFAULT 0,
     CONSTRAINT pk_StateTaxRate PRIMARY KEY (State)
);

COMMIT;
