CREATE TABLE City_Ext
(
CityID          INTEGER,
ZipCode         NVARCHAR2(50),
City            NVARCHAR2(100),
State           NVARCHAR2(50),
AreaCode        NVARCHAR2(50),
Population2010  INTEGER,
Population2000  INTEGER,
Population1990  INTEGER,
Population1980  INTEGER,
Country         NVARCHAR2(50),
Latitude        NUMBER(15,5),
Longitude       NUMBER(15,5),
SelectionCDF    NUMBER(15,5),
FIPS            INTEGER,
Income2009      NUMBER(25,4),
Income2004      NUMBER(25,4),
Division        INTEGER,
StateCode       INTEGER,
Region          INTEGER,
IntPtLat        NVARCHAR2(255),
IntPtLon        NVARCHAR2(255),
AreaLand        NVARCHAR2(255),
AreaWater       NVARCHAR2(255)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('City.csv')
)
	reject limit unlimited;

CREATE TABLE Manufacturer_Ext
(
ManufacturerID    INTEGER,
ManufacturerName  NVARCHAR2(50),
ContactName       NVARCHAR2(100),
Phone             NVARCHAR2(100),
Address           NVARCHAR2(100),
ZipCode           NVARCHAR2(50),
CityID            INTEGER,
BalanceDue        NUMBER(25,4)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by 0x'09'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Manufacturer.csv')
)
	reject limit unlimited;


CREATE TABLE WorkArea_Ext
(
WorkArea      NVARCHAR2(100),
Description   NVARCHAR2(200)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('WorkArea.csv')
)
	reject limit unlimited;

CREATE TABLE Employee_Ext
(
EmployeeID     INTEGER,
TaxpayerID     NVARCHAR2(50),
LastName       NVARCHAR2(100),
FirstName      NVARCHAR2(100),
HomePhone      NVARCHAR2(100),
Address        NVARCHAR2(100),
ZipCode        NVARCHAR2(50),
CityID         INTEGER,
DateHired      DATE,
DateReleased   DATE,
CurrentManager INTEGER,
SalaryGrade    INTEGER,
Salary         NUMBER(25,4),
Title          NVARCHAR2(200),
WorkArea       NVARCHAR2(100)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Employee.csv')
)
	reject limit unlimited;


CREATE TABLE RetailStore_Ext
(
StoreID           INTEGER,
StoreName         NVARCHAR2(100),
Phone             NVARCHAR2(100),
ContactFirstName  NVARCHAR2(50),
ContactLastName   NVARCHAR2(50),
Address           NVARCHAR2(100),
ZipCode           NVARCHAR2(50),
CityID            INTEGER
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('RetailStore.csv')
)
	reject limit unlimited;


CREATE TABLE Customer_Ext
(
CustomerID    INTEGER,
Phone         NVARCHAR2(100),
FirstName     NVARCHAR2(100),
LastName      NVARCHAR2(100),
Gender        NVARCHAR2(50),
Address       NVARCHAR2(100),
ZipCode       NVARCHAR2(100),
CityID        INTEGER,
BalanceDue    NUMBER(25,4)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Customer.csv')
)
	reject limit unlimited;


CREATE TABLE ModelType_Ext
(
ModelType     NVARCHAR2(100),
Description   NVARCHAR2(100),
ComponentID   INTEGER
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by 0x'09'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('ModelType.csv')
)
	reject limit unlimited;


CREATE TABLE ModelSize_Ext
(
ModelType       NVARCHAR2(100),
MSize           NUMBER(15,5),
TopTube         NUMBER(15,5),
ChainStay       NUMBER(15,5),
TotalLength     NUMBER(15,5),
GroundClearance NUMBER(15,5),
HeadTubeAngle   NUMBER(15,5),
SeatTubeAngle   NUMBER(15,5)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('ModelSize.csv')
)
	reject limit unlimited;


CREATE TABLE ComponentName_Ext
(
ComponentName NVARCHAR2(100),
AssemblyOrder INTEGER,
Description   NVARCHAR2(200)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('ComponentName.csv')
)
	reject limit unlimited;


CREATE TABLE Component_Ext
(
ComponentID      INTEGER,
ManufacturerID   INTEGER,
ProductNumber    NVARCHAR2(100),
Road             NVARCHAR2(50),
Category         NVARCHAR2(100),
Length           NUMBER(15,5),
Height           NUMBER(15,5),
Width            NUMBER(15,5),
Weight           NUMBER(15,5),
Year             INTEGER,
EndYear          INTEGER,
Description      NVARCHAR2(400),
ListPrice        NUMBER(25,4),
EstimatedCost    NUMBER(25,4),
QuantityOnHand   NUMBER(15,5)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Component.csv')
)
	reject limit unlimited;


CREATE TABLE TubeMaterial_Ext
(
TubeID        INTEGER,
Material      NVARCHAR2(100),
Description   NVARCHAR2(200),
Diameter      NUMBER(15,5),
Thickness     NUMBER(15,5),
Roundness     NVARCHAR2(100),
Weight        NUMBER(15,5),
Stiffness     NUMBER(15,5),
ListPrice     NUMBER(25,4),
Construction  NVARCHAR2(100)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('TubeMaterial.csv')
)
	reject limit unlimited;

CREATE TABLE Paint_Ext
(
PaintID          INTEGER,
ColorName        NVARCHAR2(100),
ColorStyle       NVARCHAR2(100),
ColorList        NVARCHAR2(100),
DateIntroduced   DATE,
DateDiscontinued DATE
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by 0x'09'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Paint.csv')
)
	reject limit unlimited;


CREATE TABLE CommonSizes_Ext
(
ModelType     NVARCHAR2(100),
FrameSize     NUMBER(15,5)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('CommonSizes.csv')
)
	reject limit unlimited;

CREATE TABLE Preference_Ext
(
ItemName      NVARCHAR2(100),
Value         NUMBER(15,5),
Description   NVARCHAR2(500),
DateChanged   DATE
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Preference.csv')
)
	reject limit unlimited;


CREATE TABLE Groupo_Ext
(
ComponentGroupID  INTEGER,
GroupName         NVARCHAR2(100),
BikeType          NVARCHAR2(100),
Year              INTEGER,
EndYear           INTEGER,
WEIGHT            NUMBER(15,5)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by 0x'09'
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Groupo.csv')
)
	reject limit unlimited;

CREATE TABLE LetterStyle_Ext
(
LetterStyle   NVARCHAR2(100),
Description   NVARCHAR2(100)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('LetterStyle.csv')
)
	reject limit unlimited;

CREATE TABLE Bicycle_Ext
(
SerialNumber     INTEGER,
CustomerID       INTEGER,
ModelType        NVARCHAR2(100),
PaintID          INTEGER,
FrameSize        NUMBER(15,5),
OrderDate        DATE,
StartDate        DATE,
ShipDate         DATE,
ShipEmployee     INTEGER,
FrameAssembler   INTEGER,
Painter          INTEGER,
Construction     NVARCHAR2(100),
WaterBottleBrazeOns INTEGER,
CustomName       NVARCHAR2(100),
LetterStyleID    NVARCHAR2(100),
StoreID          INTEGER,
EmployeeID       INTEGER,
TopTube          NUMBER(15,5),
ChainStay        NUMBER(15,5),
HeadTubeAngle    NUMBER(15,5),
SeatTubeAngle    NUMBER(15,5),
ListPrice        NUMBER(25,4),
SalePrice        NUMBER(25,4),
SalesTax         NUMBER(25,4),
SaleState        NVARCHAR2(100),
ShipPrice        NUMBER(25,4),
FramePrice       NUMBER(25,4),
ComponentList    NUMBER(25,4)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('Bicycle.csv')
)
	reject limit unlimited;


CREATE TABLE BicycleTubeUsage_Ext
(
SerialNumber     INTEGER,
TubeID           INTEGER,
Quantity         NUMBER(15,5)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('BicycleTubeUsage.csv')
)
	reject limit unlimited;


CREATE TABLE BikeParts_Ext
(
SerialNumber     INTEGER,
ComponentID      INTEGER,
SubstituteID     INTEGER,
Location         NVARCHAR2(100),
Quantity         INTEGER,
DateInstalled    DATE,
EmployeeID       INTEGER
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('BikeParts.csv')
)
	reject limit unlimited;

CREATE TABLE BikeTubes_Ext
(
SerialNumber  INTEGER,
TubeName      NVARCHAR2(100),
TubeID        INTEGER,
Length        NUMBER(15,5)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('BikeTubes.csv')
)
	reject limit unlimited;


CREATE TABLE CustomerTransaction_Ext
(
CustomerID       INTEGER,
TransactionDate  DATE,
EmployeeID       INTEGER,
Amount           NUMBER(25,4),
Description      NVARCHAR2(250),
Reference        INTEGER
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('CustomerTransaction.csv')
)
	reject limit unlimited;


CREATE TABLE GroupComponents_Ext
(
GroupID       INTEGER,
ComponentID   INTEGER
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('GroupComponents.csv')
)
	reject limit unlimited;

CREATE TABLE ManufacturerTransaction_Ext
(
ManufacturerID   INTEGER,
TransactionDate  DATE,
EmployeeID       INTEGER,
Amount           NUMBER(25,4),
Description      NVARCHAR2(500),
Reference        INTEGER
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('ManufacturerTransaction.csv')
)
	reject limit unlimited;

CREATE TABLE PurchaseOrder_Ext
(
PurchaseID      INTEGER,
EmployeeID      INTEGER,
ManufacturerID  INTEGER,
TotalList       NUMBER(25,4),
ShippingCost    NUMBER(25,4),
Discount        NUMBER(25,4),
OrderDate       DATE,
ReceiveDate     DATE,
AmountDue       NUMBER(25,4)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('PurchaseOrder.csv')
)
	reject limit unlimited;

CREATE TABLE PurchaseItem_Ext
(
PurchaseID       INTEGER,
ComponentID      INTEGER,
PricePaid        NUMBER(25,4),
Quantity         INTEGER,
QuantityReceived INTEGER
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('PurchaseItem.csv')
)
	reject limit unlimited;

CREATE TABLE RevisionHistory_Ext
(
ID               INTEGER,
Version          NVARCHAR2(100),
ChangeDate       DATE,
Name             NVARCHAR2(100),
RevisionComments NVARCHAR2(500)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('RevisionHistory.csv')
)
	reject limit unlimited;

CREATE TABLE SampleName_Ext
(
ID            INTEGER,
LastName      NVARCHAR2(100),
FirstName     NVARCHAR2(100),
Gender        NVARCHAR2(50)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('SampleName.csv')
)
	reject limit unlimited;

CREATE TABLE SampleStreet_Ext
(
ID            INTEGER,
BaseAddress   NVARCHAR2(100)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('SampleStreet.csv')
)
	reject limit unlimited;

CREATE TABLE CensusRegion_Ext
(
RegionID      INTEGER,
RegionName    NVARCHAR2(255)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('CensusRegion.csv')
)
	reject limit unlimited;

CREATE TABLE CensusDivision_Ext
(
DivisionID    INTEGER,
DivisionName  NVARCHAR2(255),
RegionID      INTEGER
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('CensusDivision.csv')
)
	reject limit unlimited;

CREATE TABLE States_Ext
(
StateCode     INTEGER,
StateAbbrev   NVARCHAR(10),
StateName     NVARCHAR2(100)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('States.csv')
)
	reject limit unlimited;


CREATE TABLE StateTaxRate_Ext
(
State         NVARCHAR2(50),
TaxRate       NUMBER(15,5)
)
organization external (
	default directory csv_dir
	access parameters (
		records delimited by newline
		fields terminated by ','
		optionally enclosed by '"' lrtrim
		missing field values are null
	)
	location ('StateTaxRate.csv')
)
	reject limit unlimited;

